.. image:: https://travis-ci.org/LoyVanBeek/m2m_certificates.svg?branch=master
    :target: https://travis-ci.org/LoyVanBeek/m2m_certificates

Python module for generating and parsing M2M format certificates
================================================================

.. _Python: https://www.python.org
.. _GitHub: https://github.com/LoyVanBeek/m2m_certificates
.. _issues: https://github.com/LoyVanBeek/m2m_certificates/issues
.. _bugs: https://github.com/LoyVanBeek/m2m_certificates/labels/bug
.. _questions: https://github.com/LoyVanBeek/m2m_certificates/labels/question
.. _NFC Forum: http://nfc-forum.org/

The **m2m_certificates** module implements the `NFC Forum`_ specification for M2M (Machine to Machine) certificates.
This is a part of the NDEF specification.

These certificates are more compact than standard x509 certificates and are thus easier to fit onto a NFC tag.
